@@ -32,8 +32,8 @@ pub use {
     num4::Num4,
     parking_lot::{Mutex, RwLock, RwLockReadGuard, RwLockWriteGuard},
     stdio::{DefaultStderr, DefaultStdin, DefaultStdout},
-    value::{RuntimeFunction, Value},
-    value_iterator::{IntRange, ValueIterator, ValueIteratorOutput},
+    value::{FunctionInfo, Value},
+    value_iterator::{ExternalIterator, IntRange, ValueIterator, ValueIteratorOutput},
     value_key::ValueKey,
     value_list::{ValueList, ValueVec},
     value_map::{DataMap, ValueMap},
